@@ -2,7 +2,7 @@ package Finance::Budget;
 
 use strict;
 use warnings;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 {   use Carp;
     use Text::CSV;
     use Date::Manip;
@@ -18,7 +18,7 @@ sub new
 
     my %self = (
         days              => 365,
-        currency          => '$',
+        currency_symbol   => '$',
         date_format       => '%m/%d/%Y',
         markup_callback   => sub { return $_[0]->{string} },
         opening_balance   => 0,
@@ -68,7 +68,7 @@ sub new
             croak sprintf '%s should be a format string', $opt
                 if $param_hr->{$opt} !~ m{ [%][a-z] }xmsi;
         }
-        else
+        elsif ( $self{$opt} =~ m{\A \d }xms )
         {
             croak sprintf '%s should be a number', $opt
                 if $param_hr->{$opt} !~ m{\A \d+ (?: [.] \d+ )? \z}xms;
@@ -98,7 +98,7 @@ sub new
 sub opening_balance
 {
     my ($self) = @_;
-    return _as_dollars( $self->{opening_balance} );
+    return _format_currency( $self->{opening_balance}, $self->{currency_symbol} );
 }
 
 sub next
@@ -250,6 +250,40 @@ sub _build_transactions {
         sort  { $a->{amount} <=> $b->{amount} }
         @{ $self->{transaction_types} };
 
+    my %amount_for;
+
+    for my $except_hr (@{ $self->{exceptions} })
+    {
+        for my $field ( keys %{$except_hr} )
+        {
+            croak "exceptions must have: { date, category, amount }"
+                if not exists $except_hr->{$field};
+        }
+
+        my $date = Date::Manip::Date->new();
+
+        my $err = $date->parse($except_hr->{date});
+
+        die sprintf "Date::Manip::Date::parse %s -- %s\n",
+            $except_hr->{date}, $err
+            if $err;
+
+        my $category = lc $except_hr->{category};
+
+        $amount_for{ $date->printf("$category:%s") } = $except_hr->{amount};
+    }
+
+    my $find_amount_cr = sub {
+        my ( $category, $epoch, $default ) = @_;
+
+        my $exception_key = lc "$category:$epoch";
+
+        return $amount_for{$exception_key}
+            if exists $amount_for{$exception_key};
+
+        return $default;
+    };
+
     my $major_payment_hit = 0;
 
     for my $type_hr (@{ $self->{transaction_types} })
@@ -270,11 +304,17 @@ sub _build_transactions {
         {
             my $epoch = $date->printf('%s');
 
+            my $amount = $find_amount_cr->(
+                $type_hr->{category},
+                $epoch, 
+                $type_hr->{amount},
+            );
+
             $events_for{$epoch} //= [];
 
             push @{ $events_for{$epoch} },
                 {   category    => $type_hr->{category},
-                    cents       => ( 100 * $type_hr->{amount} ),
+                    cents       => ( 100 * $amount ),
                     date        => $date,
                 };
         }
@@ -298,7 +338,10 @@ sub _build_transactions {
                             date_str    => $past_hr->{date_str},
                             cents       => $balance,
                             balance     => $balance,
-                            balance_str => _as_dollars($balance),
+                            balance_str => _format_currency(
+                                $balance,
+                                $self->{currency_symbol}
+                            ),
                         };
                 }
 
@@ -313,11 +356,12 @@ sub _build_transactions {
 
             push @transactions,
                 Finance::Budget::Transaction->new(
-                    {   event       => $event_hr,
-                        balance     => $balance,
-                        width       => $width,
-                        date_format => $self->{date_format},
-                        markup      => $self->{markup_callback},
+                    {   event           => $event_hr,
+                        balance         => $balance,
+                        width           => $width,
+                        date_format     => $self->{date_format},
+                        markup          => $self->{markup_callback},
+                        currency_symbol => $self->{currency_symbol},
                     }
                 );
         }
@@ -329,8 +373,8 @@ sub _build_transactions {
     return;
 }
 
-sub _as_dollars {
-    my ($cents) = @_;
+sub _format_currency {
+    my ($cents, $currency) = @_;
 
     my $sign = $cents < 0 ? '-' : '';
 
@@ -347,7 +391,7 @@ sub _as_dollars {
         $dollars = sprintf '%.2f', ( $cents / 100 );
     }
 
-    return sprintf '% 10s', "$sign\$$dollars";
+    return sprintf '% 10s', "${sign}${currency}${dollars}";
 }
 
 package Finance::Budget::Transaction;
@@ -369,13 +413,17 @@ sub new {
     $conf_hr->{event}->{title}
         = sprintf "% $conf_hr->{width}s", $conf_hr->{event}->{category};
 
-    $conf_hr->{event}->{amount}
-        = Finance::Budget::_as_dollars( $conf_hr->{event}->{cents} );
+    $conf_hr->{event}->{amount} = Finance::Budget::_format_currency(
+        $conf_hr->{event}->{cents},
+        $conf_hr->{currency_symbol}
+    );
 
     $conf_hr->{event}->{balance} = $conf_hr->{balance};
 
-    $conf_hr->{event}->{balance_str}
-        = Finance::Budget::_as_dollars( $conf_hr->{balance} );
+    $conf_hr->{event}->{balance_str} = Finance::Budget::_format_currency(
+        $conf_hr->{balance},
+        $conf_hr->{currency_symbol}
+    );
 
     $conf_hr->{event}->{string} = join ' ',
         @{ $conf_hr->{event} }{qw( date_str title amount balance_str )};
@@ -606,12 +654,16 @@ Check out budget.pl in the demo directory of this project.
 
 =item days
 
-The number of days to project into the future.
+The number of days to project into the future. The default is 365.
 
 =item date_format
 
-The format that the transactions will use on stringafication. The default
-format is '%m/%d/%Y'.
+The format that the transactions will use on stringafication. 
+The default is '%m/%d/%Y'.
+
+=item currency_symbol
+
+Set any string as a currency symbol. The default is '$'.
 
 =item markup_callback
 
@@ -630,9 +682,12 @@ The callback receives as the first argument a hash ref like:
       cents       => 0,
   }
 
+The callback retuns a formatted string. The default just returns the 'string'
+value.
+
 =item opening_balance
 
-The opening blanace, in dollars, of your checking account.
+The opening blanace, in dollars, of your checking account. The default is 0.
 
 =item transaction_types
 
